Socialize - A social network on the command line
================================================

.. image:: https://travis-ci.org/dmonn/socialize.svg?branch=master
    :target: https://travis-ci.org/dmonn/socialize

Python CLI client for 'Socialize - A social network on the command line'.

Installation
============

Use ``pip install socialize`` to install the client on your machine.
Be sure to have python and pip installed. If you haven't, please install `Python`_ and `pip`_

.. _Python: https://wiki.python.org/moin/BeginnersGuide/Download
.. _pip: https://pip.pypa.io/en/stable/installing/

Usage
=====

To use the client, please first register using ``socl register`` or login using ``socl login``.
After that, you can use ``socl help`` to get an overview.

If you want, you can consult the `API Docs`_.

.. _API Docs: https://socialize.dmonn.ch

Contributing
============

This is a community project. We love to get any feedback in the form of
`issues`_ and `pull requests`_.

.. _issues: https://github.com/dmonn/socialize/issues
.. _pull requests: https://github.com/dmonn/socialize/pulls




